- remove the DNS record for the subdomain
- regularly check your inventory and ensure the subdomain is still in use and you are still in control of everything
  your subdomains point to.
- choose your service provider wisely, and ensure they provide enough security measures to protect your subdomains.
